==> jc-1.4.0.tar.gz: polyglot/util/TypeEncoder.h <==
// public class polyglot.util.TypeEncoder

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f299688fad53c0b2 polyglot_util_TypeEncoder

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_util_TypeEncoder_H_
#define _JC_polyglot_util_TypeEncoder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_types_Type$object;
struct _jc_polyglot_types_TypeSystem$object;

// Typedefs
typedef struct _jc_polyglot_util_TypeEncoder$sub_refs	_jc_polyglot_util_TypeEncoder$sub_refs;
typedef struct _jc_polyglot_util_TypeEncoder$sub_nonrefs	_jc_polyglot_util_TypeEncoder$sub_nonrefs;
typedef struct _jc_polyglot_util_TypeEncoder$refs	_jc_polyglot_util_TypeEncoder$refs;
typedef struct _jc_polyglot_util_TypeEncoder$nonrefs	_jc_polyglot_util_TypeEncoder$nonrefs;
typedef struct _jc_polyglot_util_TypeEncoder$object	_jc_polyglot_util_TypeEncoder$object;

typedef const struct _jc_polyglot_util_TypeEncoder$vmethods	_jc_polyglot_util_TypeEncoder$vmethods;
typedef const struct _jc_polyglot_util_TypeEncoder$vtable	_jc_polyglot_util_TypeEncoder$vtable;
typedef const struct _jc_polyglot_util_TypeEncoder$vtype	_jc_polyglot_util_TypeEncoder$vtype;

// Constructors
extern void _jc_polyglot_util_TypeEncoder$method$_init$964314195388e7c0(_jc_env *, struct _jc_polyglot_util_TypeEncoder$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_object *_jc_polyglot_util_TypeEncoder$method$decode$8383d57b54a9bd76(_jc_env *, struct _jc_polyglot_util_TypeEncoder$object *, struct _jc_java_lang_String$object *);
extern struct _jc_java_lang_String$object *_jc_polyglot_util_TypeEncoder$method$encode$5a76d9ae1ffe7939(_jc_env *, struct _jc_polyglot_util_TypeEncoder$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_util_TypeEncoder$method_info$decode$8383d57b54a9bd76;
extern _jc_method _jc_polyglot_util_TypeEncoder$method_info$encode$5a76d9ae1ffe7939;

// Virtual methods structure
struct _jc_polyglot_util_TypeEncoder$vmethods {
	struct _jc_object	*(*decode$8383d57b54a9bd76)(_jc_env *, struct _jc_polyglot_util_TypeEncoder$object *, struct _jc_java_lang_String$object *);
	struct _jc_java_lang_String$object	*(*encode$5a76d9ae1ffe7939)(_jc_env *, struct _jc_polyglot_util_TypeEncoder$object *, struct _jc_object *);
};

// Vtable
struct _jc_polyglot_util_TypeEncoder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_util_TypeEncoder$vmethods	polyglot_util_TypeEncoder;
};

// Vtype
struct _jc_polyglot_util_TypeEncoder$vtype {
	_jc_type			type;
	_jc_polyglot_util_TypeEncoder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_TypeEncoder$sub_refs {
	struct _jc_object	*ts;
};

// Reference instance fields (object)
struct _jc_polyglot_util_TypeEncoder$refs {
    _jc_polyglot_util_TypeEncoder$sub_refs	polyglot_util_TypeEncoder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_TypeEncoder$sub_nonrefs {
	jboolean	zip;
	jboolean	base64;
	jboolean	test;
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_TypeEncoder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_util_TypeEncoder$sub_nonrefs	polyglot_util_TypeEncoder;
};

// Object instance structure
struct _jc_polyglot_util_TypeEncoder$object {
	_jc_polyglot_util_TypeEncoder$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_TypeEncoder$vtype	*vtype;
	_jc_polyglot_util_TypeEncoder$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_TypeEncoder$vtype _jc_polyglot_util_TypeEncoder$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_TypeEncoder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_TypeEncoder$class_object;

#endif	/* _JC_polyglot_util_TypeEncoder_H_ */

==> jc-1.4.6.tar.gz: polyglot/util/TypeEncoder.h <==
// public class polyglot.util.TypeEncoder

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f299688fad53c0b2 polyglot_util_TypeEncoder

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_util_TypeEncoder_H_
#define _JC_polyglot_util_TypeEncoder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_types_Type$object;
struct _jc_polyglot_types_TypeSystem$object;

// Typedefs
typedef struct _jc_polyglot_util_TypeEncoder$sub_refs	_jc_polyglot_util_TypeEncoder$sub_refs;
typedef struct _jc_polyglot_util_TypeEncoder$sub_nonrefs	_jc_polyglot_util_TypeEncoder$sub_nonrefs;
typedef struct _jc_polyglot_util_TypeEncoder$refs	_jc_polyglot_util_TypeEncoder$refs;
typedef struct _jc_polyglot_util_TypeEncoder$nonrefs	_jc_polyglot_util_TypeEncoder$nonrefs;
typedef struct _jc_polyglot_util_TypeEncoder$object	_jc_polyglot_util_TypeEncoder$object;

typedef const struct _jc_polyglot_util_TypeEncoder$vmethods	_jc_polyglot_util_TypeEncoder$vmethods;
typedef const struct _jc_polyglot_util_TypeEncoder$vtable	_jc_polyglot_util_TypeEncoder$vtable;
typedef const struct _jc_polyglot_util_TypeEncoder$vtype	_jc_polyglot_util_TypeEncoder$vtype;

// Constructors
extern void _jc_polyglot_util_TypeEncoder$method$_init$964314195388e7c0(_jc_env *, struct _jc_polyglot_util_TypeEncoder$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_polyglot_util_TypeEncoder$method$decode$8383d57b54a9bd76(_jc_env *, struct _jc_polyglot_util_TypeEncoder$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_polyglot_util_TypeEncoder$method$encode$5a76d9ae1ffe7939(_jc_env *, struct _jc_polyglot_util_TypeEncoder$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_util_TypeEncoder$method_info$decode$8383d57b54a9bd76;
extern _jc_method _jc_polyglot_util_TypeEncoder$method_info$encode$5a76d9ae1ffe7939;

// Virtual methods structure
struct _jc_polyglot_util_TypeEncoder$vmethods {
	struct _jc_object	*(*decode$8383d57b54a9bd76)(_jc_env *, struct _jc_polyglot_util_TypeEncoder$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*encode$5a76d9ae1ffe7939)(_jc_env *, struct _jc_polyglot_util_TypeEncoder$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_util_TypeEncoder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_util_TypeEncoder$vmethods	polyglot_util_TypeEncoder;
};

// Vtype
struct _jc_polyglot_util_TypeEncoder$vtype {
	_jc_type			type;
	_jc_polyglot_util_TypeEncoder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_TypeEncoder$sub_refs {
	struct _jc_object	*ts;
};

// Reference instance fields (object)
struct _jc_polyglot_util_TypeEncoder$refs {
    _jc_polyglot_util_TypeEncoder$sub_refs	polyglot_util_TypeEncoder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_TypeEncoder$sub_nonrefs {
	jboolean	zip;
	jboolean	base64;
	jboolean	test;
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_TypeEncoder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_util_TypeEncoder$sub_nonrefs	polyglot_util_TypeEncoder;
};

// Object instance structure
struct _jc_polyglot_util_TypeEncoder$object {
	_jc_polyglot_util_TypeEncoder$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_TypeEncoder$vtype	*vtype;
	_jc_polyglot_util_TypeEncoder$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_TypeEncoder$vtype _jc_polyglot_util_TypeEncoder$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_TypeEncoder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_TypeEncoder$class_object;

#endif	/* _JC_polyglot_util_TypeEncoder_H_ */
